/**********************************************************************
 *
 * Copyright (c) 2004 Olaf Willuhn
 * All rights reserved.
 * 
 * This software is copyrighted work licensed under the terms of the
 * Jameica License.  Please consult the file "LICENSE" for details. 
 *
 **********************************************************************/

package de.willuhn.jameica.fibu.gui.views;

import de.willuhn.jameica.fibu.Fibu;
import de.willuhn.jameica.fibu.Settings;
import de.willuhn.jameica.fibu.gui.action.GeschaeftsjahrClose;
import de.willuhn.jameica.fibu.gui.action.GeschaeftsjahrDelete;
import de.willuhn.jameica.fibu.gui.controller.GeschaeftsjahrControl;
import de.willuhn.jameica.fibu.rmi.Geschaeftsjahr;
import de.willuhn.jameica.gui.AbstractView;
import de.willuhn.jameica.gui.Action;
import de.willuhn.jameica.gui.GUI;
import de.willuhn.jameica.gui.parts.Button;
import de.willuhn.jameica.gui.parts.ButtonArea;
import de.willuhn.jameica.gui.util.Container;
import de.willuhn.jameica.gui.util.SimpleContainer;
import de.willuhn.jameica.system.Application;
import de.willuhn.util.ApplicationException;
import de.willuhn.util.I18N;

/**
 * View zum Bearbeiten eines Geschaeftsjahres.
 */
public class GeschaeftsjahrNeu extends AbstractView
{
  private final static I18N i18n = Application.getPluginLoader().getPlugin(Fibu.class).getResources().getI18N();

  /**
   * @see de.willuhn.jameica.gui.AbstractView#bind()
   */
  public void bind() throws Exception
  {
    GUI.getView().setTitle(i18n.tr("Geschftsjahr bearbeiten"));

    final GeschaeftsjahrControl control = new GeschaeftsjahrControl(this);

    Container group = new SimpleContainer(getParent());
    group.addHeadline(i18n.tr("Eigenschaften"));
    group.addLabelPair(i18n.tr("Kontenrahmen"), control.getKontenrahmenAuswahl());
    group.addLabelPair(i18n.tr("Beginn des Geschftsjahres"),control.getBeginn());
    group.addLabelPair(i18n.tr("Ende des Geschftsjahres"),control.getEnde());

    ButtonArea buttonArea = new ButtonArea();
    
    boolean canDelete = true;
    Geschaeftsjahr current = Settings.getActiveGeschaeftsjahr();
    if (current != null) canDelete = !current.equals(control.getGeschaeftsjahr());
    Button delete = new Button(i18n.tr("Lschen"),new GeschaeftsjahrDelete(),getCurrentObject(),false,"user-trash-full.png");
    delete.setEnabled(canDelete);
    buttonArea.addButton(delete);
    
    Button close = new Button(i18n.tr("Geschftsjahr abschlieen"), new GeschaeftsjahrClose(), control.getCurrentObject(),false,"go-next.png");
    close.setEnabled(!control.getGeschaeftsjahr().isNewObject() && !control.getGeschaeftsjahr().isClosed());
    buttonArea.addButton(close);
    
    Button store = new Button(i18n.tr("Speichern"), new Action()
    {
      public void handleAction(Object context) throws ApplicationException
      {
        control.handleStore();
      }
    },null,true,"document-save.png");
    store.setEnabled(!control.getGeschaeftsjahr().isClosed());
    buttonArea.addButton(store);
    
    buttonArea.paint(getParent());
  }
}


/*********************************************************************
 * $Log: GeschaeftsjahrNeu.java,v $
 * Revision 1.13  2011/05/12 09:10:31  willuhn
 * @R Back-Buttons entfernt
 * @C GUI-Cleanup
 *
 * Revision 1.12  2010-06-04 00:33:56  willuhn
 * @B Debugging
 * @N Mehr Icons
 * @C GUI-Cleanup
 *
 * Revision 1.11  2010/06/03 14:26:16  willuhn
 * @N Extension zum Zuordnen von Hibiscus-Kategorien zu SynTAX-Buchungsvorlagen
 * @C Code-Cleanup
 *
 * Revision 1.10  2010/06/02 00:02:58  willuhn
 * @N Mehr Icons
 *
 * Revision 1.9  2010/06/01 23:51:56  willuhn
 * @N Neue Icons - erster Teil
 *
 * Revision 1.8  2010/06/01 16:37:22  willuhn
 * @C Konstanten von Fibu zu Settings verschoben
 * @N Systemkontenrahmen nach expliziter Freigabe in den Einstellungen aenderbar
 * @C Unterscheidung zwischen canChange und isUserObject in UserObject
 * @C Code-Cleanup
 * @R alte CVS-Logs entfernt
 *
 * Revision 1.7  2009/07/03 10:52:18  willuhn
 * @N Merged SYNTAX_1_3_BRANCH into HEAD
 *
 * Revision 1.6.2.1  2008/09/08 09:03:51  willuhn
 * @C aktiver Mandant/aktives Geschaeftsjahr kann nicht mehr geloescht werden
 **********************************************************************/